<div class="container-fluid">
  <div class="menu-bar" [class.bg-danger]="!vortexIsOnline">
    <div class="menu-bar-left">
      <button class="btn left-button" [routerLink]="['/']">Home</button>
    </div>
    <div class="menu-title">
      <h2 class="h2">{{title}}</h2>
    </div>
    <div class="menu-bar-right">
      <div class="btn-group" role="group" aria-label="">
        <button class="btn right-button"
                *ngFor="let link of rightLinks"
                [routerLink]="[link.resourcePath]">{{linkTitle(link)}}
        </button>
      </div>
    </div>
  </div>
</div>
