<body class="home-page">
<div class="peek-main-home">
  <div class="container-fluid">
    <div *ngIf="!appDetails.length" class="text-center"><h1 class="h1">
      No Plugins Installed</h1>
    </div>
    <div class=" home-icon">
      <div class="row">
        <div class="col-xs-4">
          <a *ngFor="let app of appDetails"
             [routerLink]="[app.resourcePath]">
            <img [src]="[app.pluginIconPath]">
            <p class="text-center">{{app.title}}</p>
          </a>
        </div>
      </div>
    </div>
  </div>
</div>
</body>
