// Import the theme’s variables. If you’re using a color scheme
// other than “light”, switch the path to the alternative scheme,
// for example 'nativescript-theme-core/scss/dark'.
@import 'nativescript-theme-core/scss/light';

// Customize any of the theme’s variables here, for instance $btn-color: red;

// Import the theme’s main ruleset.
@import 'nativescript-theme-core/scss/index';

// Place any CSS rules you want to apply on both iOS and Android here.
// This is where the vast majority of your CSS code goes.


@import '@synerty/peek-mobile-theme/scss/stylesheet';


.peek-field-data-text {
    color: black;
}

/* Font Awesome style */
.fa {
  font-family: FontAwesome, fontawesome-webfont;
}




.bg-info {
    color: black;
    background-color: #d9edf7;
}

.bg-success {
    color: black;
    background-color: #dff0d8;
}

.bg-warning {
    color: black;
    background-color: #fcf8e3;
}

.bg-danger {
    color: black;
    background-color: #f2dede;
}